@@ -3,8 +3,7 @@
 
 
 class Principal(object):
-    """ Container of user specific security information
-    """
+    """Container of user specific security information"""
 
     def __init__(self, id="", roles=(), alias="", extra=""):
         self.id = id
@@ -13,15 +12,13 @@ class Principal(object):
         self.extra = extra
 
     def dump(self):
-        """ Dump principal object.
-        """
+        """Dump principal object."""
         return "\x1f".join(
             [self.id, ";".join(self.roles), self.alias, self.extra]
         )
 
     @classmethod
     def load(cls, s):
-        """ Load principal object from string.
-        """
+        """Load principal object from string."""
         id, roles, alias, extra = s.split("\x1f", 3)
         return cls(id, tuple(roles.split(";")), alias, extra)
